from typing import overload
import System
import System.Security.Authentication


class SslProtocols(System.Enum):
    """This class has no documentation."""

    NONE = 0

    SSL2 = ...

    SSL3 = ...

    TLS = ...

    TLS11 = ...

    TLS12 = ...

    TLS13 = ...

    DEFAULT = ...


class ExchangeAlgorithmType(System.Enum):
    """This class has no documentation."""

    NONE = 0

    RSA_SIGN = ...

    RSA_KEY_X = ...

    DIFFIE_HELLMAN = ...


class CipherAlgorithmType(System.Enum):
    """This class has no documentation."""

    NONE = 0

    RC2 = ...

    RC4 = ...

    DES = ...

    TRIPLE_DES = ...

    AES = ...

    AES128 = ...

    AES192 = ...

    AES256 = ...

    NULL = ...


class HashAlgorithmType(System.Enum):
    """This class has no documentation."""

    NONE = 0

    MD5 = ...

    SHA1 = ...

    SHA256 = ...

    SHA384 = ...

    SHA512 = ...





from typing import overload
import abc

import System
import System.Security.Principal


class IIdentity(metaclass=abc.ABCMeta):
    """This class has no documentation."""


class PrincipalPolicy(System.Enum):
    """This class has no documentation."""

    UNAUTHENTICATED_PRINCIPAL = 0

    NO_PRINCIPAL = 1

    WINDOWS_PRINCIPAL = 2


class IPrincipal(metaclass=abc.ABCMeta):
    """This class has no documentation."""


class TokenImpersonationLevel(System.Enum):
    """This class has no documentation."""

    NONE = 0

    ANONYMOUS = 1

    IDENTIFICATION = 2

    IMPERSONATION = 3

    DELEGATION = 4


